Learn R Programming

usethis (version 3.2.2)

proj_activate: Activate a project

Description

Activates a project in the usethis, R session, and (if relevant) RStudio or Positron senses. If you are in RStudio or Positron, this will open a new session or window. If not, it will change the working directory and active project.

Usage

proj_activate(path)

Value

Single logical value indicating if current session is modified.

Arguments

path

Project directory

Details

  • If using RStudio desktop, the project is opened in a new session.

  • If using Positron, the project is opened in a new window.

  • If using RStudio or Positron on a server, the project is opened in a new browser tab.

  • Otherwise, the working directory and active project are changed in the current R session.