Learn R Programming

usethis (version 3.2.2)

proj_sitrep: Report working directory and usethis/IDE project

Description

proj_sitrep() reports

  • current working directory

  • the active usethis project

  • the active project according to your IDE, e.g. RStudio project or current folder/workspace in Positron

Call this function if things seem weird and you're not sure what's wrong or how to fix it. Usually, all three of these should coincide (or be unset) and proj_sitrep() provides suggested commands for getting back to this happy state.

Usage

proj_sitrep()

Arguments

Value

A named list, with S3 class sitrep (for printing purposes), reporting current working directory, active usethis project, and active IDE project

See Also

Other project functions: proj_utils

Examples

Run this code
proj_sitrep()

Run the code above in your browser using DataLab