These helpers follow tidyverse conventions which are generally a little stricter than the defaults, reflecting the need for greater rigor in commonly used packages
use_tidy_ci(browse = interactive())use_tidy_description()
use_tidy_versions(overwrite = FALSE)
use_tidy_eval()
open a browser window to enable Travis builds for the package automatically.
By default (FALSE), only dependencies without version
specifications will be modified. Set to TRUE to modify all dependencies.
use_tidy_ci(): sets up travis and codecov, ensuring that the package
works on all version of R starting at 3.1.
use_tidy_description(): puts fields in standard order and alphabetises
dependencies.
use_tidy_eval(): imports a standard set of helpers to facilitate
programming with the tidy eval toolkit.
use_tidy_versions(): pins all dependencies to require at least
the currently installed version.