use_git() initialises a Git repository and adds important files to
.gitignore. If user consents, it also makes an initial commit.
Details
If there is no active project and the working directory is not inside an
existing project, use_git() treats the working directory as the project
root and initialises the Git repository there.
See also
Other git helpers:
use_git_config(),
use_git_hook(),
use_git_ignore()